@@ -6,9 +6,9 @@ var _self =
   typeof window !== "undefined"
     ? window // if in browser
     : typeof WorkerGlobalScope !== "undefined" &&
-      self instanceof WorkerGlobalScope
-    ? self // if in worker
-    : {}; // if in node js
+        self instanceof WorkerGlobalScope
+      ? self // if in worker
+      : {}; // if in node js
 
 /**
  * Prism: Lightweight, robust, elegant syntax highlighting
@@ -169,12 +169,11 @@ var Prism = (function (_self) {
             clone = [];
             visited[id] = clone;
 
-            /** @type {Array} */ (/** @type {any} */ (o)).forEach(function (
-              v,
-              i
-            ) {
-              clone[i] = deepClone(v, visited);
-            });
+            /** @type {Array} */ (/** @type {any} */ (o)).forEach(
+              function (v, i) {
+                clone[i] = deepClone(v, visited);
+              },
+            );
 
             return /** @type {any} */ (clone);
 
@@ -535,7 +534,7 @@ var Prism = (function (_self) {
       _.hooks.run("before-highlightall", env);
 
       env.elements = Array.prototype.slice.apply(
-        env.container.querySelectorAll(env.selector)
+        env.container.querySelectorAll(env.selector),
       );
 
       _.hooks.run("before-all-elements-highlight", env);
@@ -645,7 +644,7 @@ var Prism = (function (_self) {
             language: env.language,
             code: env.code,
             immediateClose: true,
-          })
+          }),
         );
       } else {
         insertHighlightedCode(_.highlight(env.code, env.grammar, env.language));
@@ -952,7 +951,7 @@ var Prism = (function (_self) {
     grammar,
     startNode,
     startPos,
-    rematch
+    rematch,
   ) {
     for (var token in grammar) {
       if (!grammar.hasOwnProperty(token) || !grammar[token]) {
@@ -1076,7 +1075,7 @@ var Prism = (function (_self) {
             token,
             inside ? _.tokenize(matchStr, inside) : matchStr,
             alias,
-            matchStr
+            matchStr,
           );
           currentNode = addAfter(tokenList, removeFrom, wrapped);
 
@@ -1099,7 +1098,7 @@ var Prism = (function (_self) {
               grammar,
               currentNode.prev,
               pos,
-              nestedRematch
+              nestedRematch,
             );
 
             // the reach might have been extended because of the rematching
@@ -1212,7 +1211,7 @@ var Prism = (function (_self) {
             _self.close();
           }
         },
-        false
+        false,
       );
     }
 
@@ -1250,7 +1249,7 @@ var Prism = (function (_self) {
     ) {
       document.addEventListener(
         "DOMContentLoaded",
-        highlightAutomaticallyCallback
+        highlightAutomaticallyCallback,
       );
     } else {
       if (window.requestAnimationFrame) {
@@ -1449,9 +1448,9 @@ Object.defineProperty(Prism.languages.markup.tag, "addInlined", {
           /__/g,
           function () {
             return tagName;
-          }
+          },
         ),
-        "i"
+        "i",
       ),
       lookbehind: true,
       greedy: true,
@@ -1481,7 +1480,7 @@ Object.defineProperty(Prism.languages.markup.tag, "addAttribute", {
           attrName +
           ")" +
           /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,
-        "i"
+        "i",
       ),
       lookbehind: true,
       inside: {
@@ -1549,7 +1548,7 @@ Prism.languages.rss = Prism.languages.xml;
           "|" +
           /(?:[^\\\r\n()"']|\\[\s\S])*/.source +
           ")\\)",
-        "i"
+        "i",
       ),
       greedy: true,
       inside: {
@@ -1565,7 +1564,7 @@ Prism.languages.rss = Prism.languages.xml;
       pattern: RegExp(
         "(^|[{}\\s])[^{}\\s](?:[^{};\"'\\s]|\\s+(?![\\s{])|" +
           string.source +
-          ")*(?=\\s*\\{)"
+          ")*(?=\\s*\\{)",
       ),
       lookbehind: true,
     },
@@ -1675,7 +1674,7 @@ Prism.languages.javascript = Prism.languages.extend("clike", {
           /(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/
             .source) +
         ")" +
-        /(?![\w$])/.source
+        /(?![\w$])/.source,
     ),
     lookbehind: true,
   },
@@ -1795,7 +1794,7 @@ if (Prism.languages.markup) {
   Prism.languages.markup.tag.addAttribute(
     /on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/
       .source,
-    "javascript"
+    "javascript",
   );
 }
 
@@ -1976,7 +1975,7 @@ Prism.languages.py = Prism.languages.python;
     indent: function (input, tabs) {
       return input.replace(
         /^[^\S\n\r]*(?=\S)/gm,
-        new Array(++tabs).join("\t") + "$&"
+        new Array(++tabs).join("\t") + "$&",
       );
     },
     breakLines: function (input, characters) {
