@@ -53,7 +53,6 @@ with contextlib.suppress(Exception):
         @line_magic
         def scrun(self, line: str = "") -> None:
             """%scrun magic: see https://github.com/plasma-umass/scalene for usage info."""
-            print("SCRUN MAGIC")
             if line:
                 sys.argv = ["scalene", "--ipython", *line.split()]
                 (args, left) = ScaleneParseArgs.parse_args()
@@ -61,7 +60,6 @@ with contextlib.suppress(Exception):
                     self.run_code(args, " ".join(left))  # type: ignore
 
     def load_ipython_extension(ip: Any) -> None:
-        print("LOADING")
         ip.register_magics(ScaleneMagics)
         with contextlib.suppress(Exception):
             # For some reason, this isn't loading correctly on the web.
