@@ -751,7 +751,9 @@ class Scalene:
             # Add the --pid field so we can propagate it to the child.
             cmdline += f" --pid={os.getpid()} ---"
             # Build the commands to pass along other arguments
-            environ = ScalenePreload.get_preload_environ(Scalene.__args)
+
+            # Since we're joining by spaces, we need to escape the spaces in the LD_LIBRARY_PATH.
+            environ = ScalenePreload.get_preload_environ(Scalene.__args, escape_spaces=True)
             if sys.platform == "win32":
                 preface = "\n".join(
                     f"set {k}={str(v)}\n" for (k, v) in environ.items()
@@ -888,6 +890,8 @@ class Scalene:
             if "is_child" in json_output:
                 return True
             outfile = Scalene.__output.output_file
+            if Scalene.__args.outfile:
+                outfile = Scalene.__args.outfile
             # If there was no output file specified, print to the console.
             if not outfile:
                 if sys.platform == "win32":
@@ -1864,14 +1868,14 @@ class Scalene:
             ):
                 return exit_status
 
-            generate_html(
-                profile_fname=Scalene.__profile_filename,
-                output_fname=(
-                    Scalene.__args.outfile
-                    if Scalene.__args.outfile
-                    else Scalene.__profiler_html
-                ),
-            )
+            if Scalene.__args.web:
+                # Only generate HTML file if needed for display in the browser.
+                generate_html(
+                    profile_fname=Scalene.__profile_filename,
+                    output_fname=(
+                        Scalene.__profiler_html
+                    ),
+                )
             if Scalene.in_jupyter():
                 from scalene.scalene_jupyter import ScaleneJupyter
 
@@ -1891,12 +1895,9 @@ class Scalene:
                     # See also scalene/scalene_preload.py
                     old_dyld = os.environ.pop("DYLD_INSERT_LIBRARIES", "")
                     old_ld = os.environ.pop("LD_PRELOAD", "")
-                    if Scalene.__args.outfile:
-                        output_fname = Scalene.__args.outfile
-                    else:
-                        output_fname = (
-                            f"{os.getcwd()}{os.sep}{Scalene.__profiler_html}"
-                        )
+                    output_fname = (
+                        f"{os.getcwd()}{os.sep}{Scalene.__profiler_html}"
+                    )
                     if Scalene.__pid == 0:
                         # Only open a browser tab for the parent.
                         dir = os.path.dirname(__file__)
