@@ -1,4 +1,14 @@
 #!/usr/bin/env python3
+
+import builtins
+
+try:
+    builtins.profile
+except AttributeError:
+    # No line profiler, provide a pass-through version
+    def profile(func): return func
+    builtins.profile = profile
+
 import numpy as np
 
 #import math
@@ -63,4 +73,3 @@ import sys
 # print("TESTME")
 # print(sys.argv)
 stuff()
-
